==> php-residence_0.2.4.tar.gz: php-residence/includes/lang/en/inizio.php <==
<?php

switch ($messaggio) {

case "Men principale dell'anno":             	$messaggio = "Main menu of year"; break;
case "Inserisci una nuova prenotazione":      	$messaggio = "Insert a new reservation"; break;
case "Visualizza e modifica le prenotazioni": 	$messaggio = "View and modify the reservations"; break;
case "del mese di":                         	$messaggio = "in"; break;
case "Gennaio":                               	$messaggio = "January"; break;
case "Febbraio":                              	$messaggio = "February"; break;
case "Marzo":                                 	$messaggio = "March"; break;
case "Aprile":      				$messaggio = "April"; break;
case "Maggio":                           	$messaggio = "May"; break;
case "Giugno":                            	$messaggio = "June"; break;
case "Luglio":                            	$messaggio = "July"; break;
case "Agosto":  				$messaggio = "August"; break;
case "Settembre":  				$messaggio = "September"; break;
case "Ottobre":  				$messaggio = "October"; break;
case "Novembre":  				$messaggio = "November"; break;
case "Dicembre":  				$messaggio = "Dicember"; break;
case "Visualizza la tabella":  			$messaggio = "View the table"; break;
case "con":  					$messaggio = "with"; break;
case "tutte le prenotazioni":  			$messaggio = "all the reservations"; break;
case "le spese e le entrate":  			$messaggio = "receipts and payments"; break;
case "i periodi e le tariffe":  		$messaggio = "the periods and the fares"; break;
case "tutti i clienti":  			$messaggio = "all the clients"; break;
case "le regole di assegnazione":  		$messaggio = "the assignation rules"; break;
case "tutti gli appartamenti":  		$messaggio = "all the apartments"; break;
case "Inserisci o modifica i dati di un cliente":	$messaggio = "Insert or modify a client's data"; break;
case "Inserisci le spese e le entrate":  	$messaggio = "Insert cash receipts and payments"; break;
case "Controlla la disponibilit":  		$messaggio = "Check the availability"; break;
case "dal":  					$messaggio = "from"; break;
case "al":  					$messaggio = "to"; break;
case "per":  					$messaggio = "for"; break;
case "persone":	  				$messaggio = "people"; break;
case "Inserisci o modifica i prezzi":  		$messaggio = "Insert or modify the prices"; break;
case "Inserisci o modifica le regole di assegnazione":  $messaggio = "Insert or modify the assignation rules"; break;
case "Personalizza":  				$messaggio = "Customize"; break;
case "richiedi l'anno":  			$messaggio = "Go to year"; break;
case "vai":  					$messaggio = "go"; break;
case "Non esiste l'anno ":  			$messaggio = "The year "; break;
case " nel database":  				$messaggio = " does not exist in the database"; break;
case "Crea l'anno":  				$messaggio = "Create the year"; break;
case "Domenica":  				$messaggio = "Sunday"; break;
case "Luned":  				$messaggio = "Monday"; break;
case "Marted":  				$messaggio = "Tuesday"; break;
case "Mercoled":  				$messaggio = "Wednesday"; break;
case "Gioved":  				$messaggio = "Thursday"; break;
case "Venerd":  				$messaggio = "Friday"; break;
case "Sabato":	 		 		$messaggio = "Saturday"; break;
case "come giorno di inizio/fine locazione":	$messaggio = "as day of beginning/end rental"; break;
case "con periodi":  				$messaggio = "with"; break;
case "settimanali":  				$messaggio = "weekly periods"; break;
case "giornalieri":  				$messaggio = "daily periods"; break;
case "e prenotazioni da":  			$messaggio = "and reservations from"; break;
case "a":  					$messaggio = "to"; break;
case "Gen. anno successivo":                    $messaggio = "Jan. next year"; break;
case "Feb. anno successivo":                   	$messaggio = "Feb. next year"; break;
case "Mar. anno successivo":                   	$messaggio = "Mar. next year"; break;
case "Apr. anno successivo":      		$messaggio = "Apr. next year"; break;
case "Mag. anno successivo":                    $messaggio = "May next year"; break;
case "Giu. anno successivo":                   	$messaggio = "June next year"; break;
case "Lug. anno successivo":                    $messaggio = "July next year"; break;
case "Ago. anno successivo":  			$messaggio = "Aug. next year"; break;
case "Set. anno successivo":  			$messaggio = "Sep. next year"; break;
case "Ott. anno successivo":  			$messaggio = "Oct. next year"; break;
case "Nov. anno successivo":  			$messaggio = "Nov. next year"; break;
case "Dic. anno successivo":  			$messaggio = "Dic. next year"; break;
case "Gen. 2 anni successivi":  		$messaggio = "Jan. 2 years later"; break;
case "Importa dall'anno precedente prenotazioni, tariffe (compresi costi aggiuntivi) e 
regole d'assegnazione relative a quest'anno.":  $messaggio = "Import from previous year reservations, fares (inclusive the extra costs) and assignation rules that refer to this year."; break;
case "Anno ":  					$messaggio = "Year "; break;
case " creato":  				$messaggio = " created"; break;
case "Non ci sono periodi che riguardano il ":  $messaggio = "There are no periods regarding "; break;
case " nel ":  					$messaggio = " in "; break;
case ", o il giorno di inizio/fine locazione era differente, sono stati importati solo i dati riguardanti costi
 aggiuntivi, caparra, nome delle tariffe e regole di assegnazione 2":  	$messaggio = ", or the day of beginning/end rental was different, only data about extra costs, deposit, the names of the fares and the assignation rules 2 has been imported"; break;
case "Attenzione</b></font>: i periodi del ":  	$messaggio = "Warning</b></font>: the periods of "; break;
case " finivano dopo quelli del ":  		$messaggio = " ended after the ones of "; break;
case " e vi erano":  				$messaggio = " and there were"; break;
case "prenotazioni che finivano dopo il limite posto al ":	$messaggio = "reservations that ended after the limit given for "; break;
case ", queste prenotazioni non sono state importate":	$messaggio = ", these reservations have not been imported"; break;
case "Anno gi creato": 			$messaggio = "Year already created"; break;
case " Do":  					$messaggio = " Su"; break;
case " Lu":  					$messaggio = " Mo"; break;
case " Ma":  					$messaggio = " Tu"; break;
case " Me":  					$messaggio = " We"; break;
case " Gi":  					$messaggio = " Th"; break;
case " Ve":  					$messaggio = " Fr"; break;
case " Sa":  					$messaggio = " Sa"; break;
case "Gen":  					$messaggio = "Jan"; break;
case "Feb":  					$messaggio = "Feb"; break;
case "Mar":  					$messaggio = "Mar"; break;
case "Apr":  					$messaggio = "Apr"; break;
case "Mag":  					$messaggio = "May"; break;
case "Giu":  					$messaggio = "Jun"; break;
case "Lug":  					$messaggio = "Jul"; break;
case "Ago":  					$messaggio = "Aug"; break;
case "Set":  					$messaggio = "Sep"; break;
case "Ott":  					$messaggio = "Oct"; break;
case "Nov":  					$messaggio = "Nov"; break;
case "Dic":  					$messaggio = "Dec"; break;
case "Il formato dell'anno richiesto  sbagliato":	$messaggio = "The format of the requested year is wrong"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;


} # fine switch ($messaggio)

?>

==> php-residence_0.3.tar.gz: php-residence/includes/lang/en/inizio.php <==
<?php

switch ($messaggio) {

case "Men principale dell'anno":             	$messaggio = "Main menu of year"; break;
case "Inserisci una nuova prenotazione":      	$messaggio = "Insert a new reservation"; break;
case "Visualizza e modifica le prenotazioni": 	$messaggio = "View and modify the reservations"; break;
case "del mese di":                         	$messaggio = "in"; break;
case "Gennaio":                               	$messaggio = "January"; break;
case "Febbraio":                              	$messaggio = "February"; break;
case "Marzo":                                 	$messaggio = "March"; break;
case "Aprile":      				$messaggio = "April"; break;
case "Maggio":                           	$messaggio = "May"; break;
case "Giugno":                            	$messaggio = "June"; break;
case "Luglio":                            	$messaggio = "July"; break;
case "Agosto":  				$messaggio = "August"; break;
case "Settembre":  				$messaggio = "September"; break;
case "Ottobre":  				$messaggio = "October"; break;
case "Novembre":  				$messaggio = "November"; break;
case "Dicembre":  				$messaggio = "Dicember"; break;
case "Visualizza la tabella":  			$messaggio = "View the table"; break;
case "con":  					$messaggio = "with"; break;
case "tutte le prenotazioni":  			$messaggio = "all the reservations"; break;
case "le spese e le entrate":  			$messaggio = "receipts and payments"; break;
case "i periodi e le tariffe":  		$messaggio = "the periods and the fares"; break;
case "tutti i clienti":  			$messaggio = "all the clients"; break;
case "le regole di assegnazione":  		$messaggio = "the assignation rules"; break;
case "tutti gli appartamenti":  		$messaggio = "all the apartments"; break;
case "Inserisci o modifica i dati di un cliente":	$messaggio = "Insert or modify a client's data"; break;
case "Inserisci le spese e le entrate":  	$messaggio = "Insert cash receipts and payments"; break;
case "Controlla la disponibilit":  		$messaggio = "Check the availability"; break;
case "dal":  					$messaggio = "from"; break;
case "al":  					$messaggio = "to"; break;
case "per":  					$messaggio = "for"; break;
case "persone":	  				$messaggio = "people"; break;
case "Inserisci o modifica i prezzi":  		$messaggio = "Insert or modify the prices"; break;
case "Inserisci o modifica le regole di assegnazione":  $messaggio = "Insert or modify the assignation rules"; break;
case "Configura e personalizza":	$messaggio = "Configure and customize"; break;
case "richiedi l'anno":  			$messaggio = "Go to year"; break;
case "vai":  					$messaggio = "go"; break;
case "Non esiste l'anno ":  			$messaggio = "The year "; break;
case " nel database":  				$messaggio = " does not exist in the database"; break;
case "Crea l'anno":  				$messaggio = "Create the year"; break;
case "Domenica":  				$messaggio = "Sunday"; break;
case "Luned":  				$messaggio = "Monday"; break;
case "Marted":  				$messaggio = "Tuesday"; break;
case "Mercoled":  				$messaggio = "Wednesday"; break;
case "Gioved":  				$messaggio = "Thursday"; break;
case "Venerd":  				$messaggio = "Friday"; break;
case "Sabato":	 		 		$messaggio = "Saturday"; break;
case "come giorno di inizio/fine locazione":	$messaggio = "as day of beginning/end rental"; break;
case "con periodi":  				$messaggio = "with"; break;
case "settimanali":  				$messaggio = "weekly periods"; break;
case "giornalieri":  				$messaggio = "daily periods"; break;
case "e prenotazioni da":  			$messaggio = "and reservations from"; break;
case "a":  					$messaggio = "to"; break;
case "Gen. anno successivo":                    $messaggio = "Jan. next year"; break;
case "Feb. anno successivo":                   	$messaggio = "Feb. next year"; break;
case "Mar. anno successivo":                   	$messaggio = "Mar. next year"; break;
case "Apr. anno successivo":      		$messaggio = "Apr. next year"; break;
case "Mag. anno successivo":                    $messaggio = "May next year"; break;
case "Giu. anno successivo":                   	$messaggio = "June next year"; break;
case "Lug. anno successivo":                    $messaggio = "July next year"; break;
case "Ago. anno successivo":  			$messaggio = "Aug. next year"; break;
case "Set. anno successivo":  			$messaggio = "Sep. next year"; break;
case "Ott. anno successivo":  			$messaggio = "Oct. next year"; break;
case "Nov. anno successivo":  			$messaggio = "Nov. next year"; break;
case "Dic. anno successivo":  			$messaggio = "Dic. next year"; break;
case "Gen. 2 anni successivi":  		$messaggio = "Jan. 2 years later"; break;
case "Importa dall'anno precedente prenotazioni, tariffe (compresi costi aggiuntivi) e 
regole d'assegnazione relative a quest'anno.":  $messaggio = "Import from previous year reservations, fares (inclusive the extra costs) and assignation rules that refer to this year."; break;
case "Anno ":  					$messaggio = "Year "; break;
case " creato":  				$messaggio = " created"; break;
case "Non ci sono periodi che riguardano il ":  $messaggio = "There are no periods regarding "; break;
case " nel ":  					$messaggio = " in "; break;
case ", o il giorno di inizio/fine locazione era differente, sono stati importati solo i dati riguardanti costi
 aggiuntivi, caparra, nome delle tariffe e regole di assegnazione 2":  	$messaggio = ", or the day of beginning/end rental was different, only data about extra costs, deposit, the names of the fares and the assignation rules 2 has been imported"; break;
case "Attenzione</b></font>: i periodi del ":  	$messaggio = "Warning</b></font>: the periods of "; break;
case " finivano dopo quelli del ":  		$messaggio = " ended after the ones of "; break;
case " e vi erano":  				$messaggio = " and there were"; break;
case "prenotazioni che finivano dopo il limite posto al ":	$messaggio = "reservations that ended after the limit given for "; break;
case ", queste prenotazioni non sono state importate":	$messaggio = ", these reservations have not been imported"; break;
case "Anno gi creato": 			$messaggio = "Year already created"; break;
case " Do":  					$messaggio = " Su"; break;
case " Lu":  					$messaggio = " Mo"; break;
case " Ma":  					$messaggio = " Tu"; break;
case " Me":  					$messaggio = " We"; break;
case " Gi":  					$messaggio = " Th"; break;
case " Ve":  					$messaggio = " Fr"; break;
case " Sa":  					$messaggio = " Sa"; break;
case "Gen":  					$messaggio = "Jan"; break;
case "Feb":  					$messaggio = "Feb"; break;
case "Mar":  					$messaggio = "Mar"; break;
case "Apr":  					$messaggio = "Apr"; break;
case "Mag":  					$messaggio = "May"; break;
case "Giu":  					$messaggio = "Jun"; break;
case "Lug":  					$messaggio = "Jul"; break;
case "Ago":  					$messaggio = "Aug"; break;
case "Set":  					$messaggio = "Sep"; break;
case "Ott":  					$messaggio = "Oct"; break;
case "Nov":  					$messaggio = "Nov"; break;
case "Dic":  					$messaggio = "Dec"; break;
case "Il formato dell'anno richiesto  sbagliato":	$messaggio = "The format of the requested year is wrong"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;


} # fine switch ($messaggio)

?>
